@@ -86,7 +86,8 @@ Blockly.Python.python_opencv_color_block= function(a) {
 Blockly.Python.python_opencv_opencam = function(a) {
     Blockly.Python.definitions_['Opencv'] = 'import cv2';
     var id = Blockly.Python.valueToCode(this,'NAME',Blockly.Python.ORDER_ASSIGNMENT);
-    var code = 'cv2.VideoCapture('+id+')';
+    var api = this.getFieldValue('API')
+    var code = 'cv2.VideoCapture('+id+','+api+')';
     return [code,Blockly.Python.ORDER_ATOMIC];
 }
 
