@@ -276,6 +276,7 @@ function sidecodeClick(){
   document.getElementById('sidebar').className='right-top';
   document.getElementById('mid_td').style.display = 'none';
   sidecodeDisplay=false;
+  
   }else{
   document.getElementById('side_code_parent').style.display = '';
   document.getElementById('sidebar').className='right-top2';
@@ -283,6 +284,8 @@ function sidecodeClick(){
   sidecodeDisplay=true;
   }
   Blockly.fireUiEvent(window, 'resize');
+  onresize()
+  document.getElementById('monaco').style.width='100%'
 }
 
 function changeThemeFile( theme )
@@ -661,7 +664,7 @@ function mySplit(str,leng){
 function add(txt) {
     list_num = list_num+1
     list_nums = list_nums+1
-    if(list_num>300){
+    if(list_num>3000){
     clears()
     list_num=0
     list_nums=0
@@ -828,8 +831,31 @@ function QuickDemo(){
     resizable:true,
     resizeOpacity: 1,
   });
-  $("#file_content").PopupWindow({
+  $("#cmd_model").PopupWindow({
     height      : 620,
+    width       : 880,
+    title       : "终端",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : true,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:true,
+  resizeOpacity: 1,
+});
+  $("#file_content").PopupWindow({
+    height      : 570,
     width       : 1000,
     title       : "文件管理",
     autoOpen    : false,
@@ -851,6 +877,29 @@ function QuickDemo(){
   resizable:true,
   resizeOpacity: 1,
 });
+$("#ssh_content").PopupWindow({
+  height      : 570,
+  width       : 1000,
+  title       : "SSH",
+  autoOpen    : false,
+  buttons         : {
+    close           : true,          // Boolean
+    maximize        : true,          // Boolean
+    collapse        : true,          // Boolean
+    minimize        : true,          // Boolean
+},
+buttonsTexts        : {
+  close               : "退出",
+  maximize            : "最大化",
+  minimize            : "最小化",
+  collapse            : "搜索",
+}, 
+draggable           : true,
+nativeDrag          : true,
+dragOpacity         : 1,
+resizable:true,
+resizeOpacity: 1,
+});
 $("#HSV_content").PopupWindow({
   height      : 660,
   width       : 1000,
@@ -1053,6 +1102,13 @@ resizeOpacity: 1,
       $("#file_content").PopupWindow("open");
       file_list()
   });
+  $("#sshmodel").on("click", function(event){
+    var sshaddr=window.location.origin.split(':')
+    console.log(sshaddr)
+    document.getElementById('ssh_').innerHTML='<iframe src="'+sshaddr[0]+':'+sshaddr[1]+':8123" width="100%" height="100%" frameborder="0" scrolling="no"></iframe>'
+    $("#ssh_content").PopupWindow("open");
+    
+});
   $("#Rexample").on("click", function(event){
     $("#Rexample_content").PopupWindow("open");
     c_list()
@@ -1074,11 +1130,18 @@ resizeOpacity: 1,
   $("#HSVmodel").on("click", function(event){
     $("#HSV_content").PopupWindow("open");
   });
+  $("#cmd_model_click").on("click", function(event){
+    $("#cmd_model").PopupWindow("open");
+    cmd_model_to()
+  });
   $("#DKmodel").on("click", function(event){
     var dk=chatSocket.send(JSON.stringify({'msg':'remote_desktop'}))
     $("#DK_content").PopupWindow("open");
   });
 }
+$("#cmd_model").on("close.popupwindow", function(event){
+  cmd_model_close()
+})
 
 $("#pip_content").on("open.popupwindow", function(event){
   var models=document.getElementsByClassName('popupwindow_overlay')
@@ -2005,3 +2068,34 @@ function sx_com(){
 }
 
 
+function cmd_model_to(){
+  var cmdl=document.getElementById("cmd_two")
+  cmdl.style.zIndex=999
+  cmdl.height='100%'
+  document.getElementById("cmd_").style.height='93%'
+  document.getElementById("cmd_model_click").style.display = 'none'
+  document.getElementById("cmd_models").appendChild(cmdl)
+  var blockly_box = document.getElementById("blockly_box")
+  blockly_box.style.height = '90%'
+  onresize()
+}
+
+function cmd_model_close(){
+  var cmdl=document.getElementById("cmd_two")
+  document.getElementById("cmd_").style.height='83%'
+  document.getElementById("cmd_model_click").style.display = 'block'
+  document.getElementById("cmd_one").appendChild(cmdl)
+  var blockly_box = document.getElementById("blockly_box")
+  blockly_box.style.height = '70%'
+  onresize()
+}
+var font_size=15
+function add_fontsize(){
+  if (font_size<30){font_size += 1}
+  document.getElementById('cmd_').style.fontSize=font_size+'px'
+}
+
+function subtract_fontsize(){
+  if (font_size>12){font_size -= 1}
+  document.getElementById('cmd_').style.fontSize=font_size+'px'
+}
\ No newline at end of file
