@@ -74,8 +74,9 @@ PopupWindow - The ultimate popup/dialog/modal jQuery plugin
             "position"          : "fixed",
             "top"               : "0",
             "left"              : "0",
-            "width"             : "100%",
-            "height"            : "100%"
+            'width'             :"100%",
+            'height'            :"100%",
+            'pointer-events'    :'none',
         },
         minplaceholder : {
             "box-sizing"        : "border-box",
@@ -327,7 +328,7 @@ PopupWindow - The ultimate popup/dialog/modal jQuery plugin
         })
         .css(_css.overlay)
         .appendTo(_mainContainer);
-        if (settings.modal) overlay.css("pointer-events", "auto");
+        if (settings.modal) overlay.css("pointer-events", "none");
         
         // Minimized Placeholder
         var minPlaceholder = $("<div>", {
