@@ -204,9 +204,9 @@ Blockly.Blocks.yolo_fast_init= {
     init: function() {
     this.appendValueInput("NAME")
         .setCheck(null)
-        .appendField("运行实时音频分类器,返回结果");
+        .appendField("运行");
     this.appendDummyInput()
-        .appendField("结果");
+        .appendField("实时音频分类器,返回结果");
     this.setInputsInline(true);
     this.setOutput(true, null);
     this.setStyle('AI_blocks');
