@@ -193,6 +193,9 @@ Blockly.Blocks.python_opencv_imread= {
     this.appendValueInput("NAME")
         .setCheck(Number)
         .appendField(" ID");
+    this.appendDummyInput()
+        .appendField("后端标识符")
+        .appendField(new Blockly.FieldDropdown([["自动检测","cv2.CAP_ANY"],["cv2.CAP_DSHOW","cv2.CAP_DSHOW"],["cv2.CAP_V4L","cv2.CAP_V4L"],["cv2.CAP_FFMPEG","cv2.CAP_FFMPEG"],["cv2.CAP_IMAGES","cv2.CAP_IMAGES"],["cv2.CAP_OPENCV_MJPEG","cv2.CAP_OPENCV_MJPEG"]]), "API");
     this.setInputsInline(true);
     this.setOutput(true, null);
     this.setStyle('OpenCV_blocks');
